documentationtools.GraphvizEdge
===============================

.. abjad-lineage:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge

.. autoclass:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.attributes
      ~abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.head
      ~abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.head_port_position
      ~abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.is_directed
      ~abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.tail
      ~abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.tail_port_position
      ~abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.__call__
      ~abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.__eq__
      ~abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.__format__
      ~abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.__hash__
      ~abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.__ne__
      ~abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.__repr__

Bases
-----

- :py:class:`documentationtools.GraphvizObject <abjad.tools.documentationtools.GraphvizObject.GraphvizObject>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.attributes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.head
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.tail
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.head_port_position
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.is_directed
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.tail_port_position
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.__call__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.__format__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.__hash__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizEdge.GraphvizEdge.__repr__
   :noindex:
